Index: trunk/psModules/src/camera/pmHDU.h
===================================================================
--- trunk/psModules/src/camera/pmHDU.h	(revision 7017)
+++ trunk/psModules/src/camera/pmHDU.h	(revision 7717)
@@ -6,5 +6,5 @@
 {
     psString extname;                   // The extension name
-    bool phu;                           // Is this the FITS Primary Header Unit
+    bool blankPHU;                      // Is this a blank FITS Primary Header Unit, i.e., no data?
     psMetadata *format;                 // The camera format
     psMetadata *header;                 // The FITS header, or NULL if primary for FITS; or section info
